@@ -1,8 +1,8 @@
-#' Fetch SoilGrids 250m properties information from point locations
+#' Get SoilGrids 250m properties information from point locations
 #'
 #' This function obtains SoilGrids properties information (250m raster resolution) given a \code{data.frame} containing site IDs, latitudes and longitudes. 
 #' 
-#' The depth intervals returned are: \code{"0-5cm", "5-15cm", "15-30cm", "30-60cm", "60-100cm", "100-200cm"} and the properties returned are \code{"bdod", "cec", "cfvo", "clay", "nitrogen", "phh2o", "sand", "silt", "soc"} -- each with 5th, 50th, 95th, mean and uncertainty values. Point data requests are made through \code{properties/query} endpoint of the SoilGrids v2.0 REST API: https://rest.soilgrids.org/soilgrids/v2.0/docs
+#' The depth intervals returned are: \code{"0-5cm", "5-15cm", "15-30cm", "30-60cm", "60-100cm", "100-200cm"} and the properties returned are \code{"bdod", "cec", "cfvo", "clay", "nitrogen", "phh2o", "sand", "silt", "soc"} -- each with 5th, 50th, 95th, mean and uncertainty values. Point data requests are made through \code{properties/query} endpoint of the SoilGrids v2.0 REST API: https://rest.isric.org/soilgrids/v2.0/docs/
 #'
 #' @param locations A \code{data.frame} containing 3 columns referring to site ID, latitude and longitude.
 #' 
@@ -25,9 +25,10 @@
 #'                            lon = c(-120.3, -121.5), 
 #'                            stringsAsFactors = FALSE)
 #'
-#'   x <- fetchSoilGrids(your.points)
+#'   x <- try(fetchSoilGrids(your.points))
 #'  
-#'   plotSPC(x, name = NA, color = "socQ50")
+#'   if (!inherits(x, 'try-error'))
+#'    plotSPC(x, name = NA, color = "socQ50")
 #'  }
 #' }
 fetchSoilGrids <- function(locations, loc.names = c("id","lat","lon")) {
@@ -44,7 +45,7 @@ fetchSoilGrids <- function(locations, loc.names = c("id","lat","lon")) {
     lat <- as.numeric(yd[[loc.names[[2]]]])
     lon <- as.numeric(yd[[loc.names[[3]]]])
     
-    response <- httr::GET(sprintf("https://rest.soilgrids.org/soilgrids/v2.0/properties/query?lat=%s&lon=%s", lat, lon))
+    response <- httr::GET(sprintf("https://rest.isric.org/soilgrids/v2.0/properties/query?lat=%s&lon=%s", lat, lon))
     r.content <- httr::content(response, as = "text", encoding = "UTF-8")
     res <- jsonlite::fromJSON(r.content)
     
