@@ -1,7 +1,4 @@
-get_projectmapunit_from_NASIS <- function(SS = TRUE, stringsAsFactors = default.stringsAsFactors()) {
-  # must have RODBC installed
-  if(!requireNamespace('RODBC'))
-    stop('please install the `RODBC` package', call.=FALSE)
+get_projectmapunit_from_NASIS <- function(SS = TRUE, stringsAsFactors = default.stringsAsFactors(), dsn = NULL) {
 
   q <- paste("SELECT p.projectiid, p.uprojectid, p.projectname, pmu.seqnum pmu_seqnum, a2.areasymbol, lmu.musym, lmu.lmapunitiid AS mukey, mu.nationalmusym, mutype, lmu.mustatus, muname, muacres
 
@@ -23,28 +20,24 @@ get_projectmapunit_from_NASIS <- function(SS = TRUE, stringsAsFactors = default.
   )
 
   # toggle selected set vs. local DB
-  if(SS == FALSE) {
+  if (SS == FALSE) {
     q <- gsub(pattern = '_View_1', replacement = '', x = q, fixed = TRUE)
   }
 
-  channel <- .openNASISchannel()
-  if (channel == -1)
+  channel <- dbConnectNASIS(dsn)
+
+  if (inherits(channel, 'try-error'))
     return(data.frame())
 
   # exec query
-  d.project <- RODBC::sqlQuery(channel, q, stringsAsFactors=FALSE)
+  d.project <- dbQueryNASIS(channel, q)
 
   # test is selected set is empty
   if (nrow(d.project) == 0) message("your selected set is missing the project table, please load it and try again")
 
   # uncode metadata domains
-  d.project <- uncode(d.project, stringsAsFactors = stringsAsFactors)
-
-
-  # close connection
-  RODBC::odbcClose(channel)
-
+  d.project <- uncode(d.project, stringsAsFactors = stringsAsFactors, dsn = dsn)
 
   # done
   return(d.project)
-  }
+}
