@@ -13,9 +13,10 @@ test_that("SDA interpretations (dominant component) works", {
                                 method = "Dominant Component", areasymbols = target_areas)
   expect_equal(nrow(res), target_area_rows)
 
-  res <- get_SDA_interpretation("FOR - Potential Seedling Mortality",
+  res <- get_SDA_interpretation(c("FOR - Potential Seedling Mortality",
+                                  "FOR - Road Suitability (Natural Surface)"),
                                 method = "Dominant Component", mukeys = target_mukeys)
-  expect_equal(sort(res$MUKEY), sort(target_mukeys))
+  expect_equal(sort(res$mukey), sort(target_mukeys))
 })
 
 test_that("SDA interpretations (dominant condition) works", {
@@ -28,9 +29,10 @@ test_that("SDA interpretations (dominant condition) works", {
   expect_equal(nrow(res), target_area_rows)
 
 
-  res <- get_SDA_interpretation("FOR - Potential Seedling Mortality",
+  res <- get_SDA_interpretation(c("FOR - Potential Seedling Mortality",
+                                  "FOR - Road Suitability (Natural Surface)"),
                                 method = "Dominant Condition", mukeys = target_mukeys)
-  expect_equal(sort(res$MUKEY), sort(target_mukeys))
+  expect_equal(sort(res$mukey), sort(target_mukeys))
 })
 
 test_that("SDA interpretations (weighted average) works", {
@@ -43,20 +45,22 @@ test_that("SDA interpretations (weighted average) works", {
   expect_equal(nrow(res), target_area_rows)
 
 
-  res <- get_SDA_interpretation("FOR - Potential Seedling Mortality",
+  res <- get_SDA_interpretation(c("FOR - Potential Seedling Mortality",
+                                  "FOR - Road Suitability (Natural Surface)"),
                                 method = "Weighted Average", mukeys = target_mukeys)
-  expect_equal(sort(res$MUKEY), sort(target_mukeys))
+  expect_equal(sort(res$mukey), sort(target_mukeys))
 })
 
 test_that("SDA interpretations (no aggregation) works", {
   skip_if_offline()
-  
+
   skip_on_cran()
-  
-  res <- get_SDA_interpretation("FOR - Potential Seedling Mortality",
-                                method = "NONE", 
+
+  res <- get_SDA_interpretation(c("FOR - Potential Seedling Mortality",
+                                  "FOR - Road Suitability (Natural Surface)"),
+                                method = "NONE",
                                 areasymbols = target_areas)
   expect_equal(nrow(res), target_area_rows_all)
-  
-  
+
+
 })
